PathError

Enum PathError 

pub enum PathError {
Show 13 variants DoesNotExist(PathBuf), Empty, ExistsAlready(PathBuf), ExtensionNotFound(PathBuf), FailedToString(PathBuf), FileNameNotFound(PathBuf), InvalidExpansion(PathBuf), IsNotDir(PathBuf), IsNotExec(PathBuf), IsNotFile(PathBuf), IsNotFileOrSymlinkToFile(PathBuf), MultipleHomeSymbols(PathBuf), ParentNotFound(PathBuf),
}

Variants



DoesNotExist(PathBuf)

An error indicating that the path does not exist.



Empty

An error indicating that the path is empty.



ExistsAlready(PathBuf)

An error indicating that the path exists already.



ExtensionNotFound(PathBuf)

An error indicating that the path does not have an extension.



FailedToString(PathBuf)

An error indicating a failure to convert the path to a string.



FileNameNotFound(PathBuf)

An error indicating that the path does not contain a filename.



InvalidExpansion(PathBuf)

An error indicating that the path failed to expand properly.



IsNotDir(PathBuf)

An error indicating that the path is not a directory.



IsNotExec(PathBuf)

An error indicating that the path is not an executable file.



IsNotFile(PathBuf)

An error indicating that the path is not a file.



IsNotFileOrSymlinkToFile(PathBuf)

An error indicating that the path is not a file or symlink to a file.



MultipleHomeSymbols(PathBuf)

An error indicating that the path contains multiple user home symbols i.e. tilda.



ParentNotFound(PathBuf)

An error indicating that the path does not have a valid parent path.

Implementations

Source

impl PathError

pub fn does_not_exist<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path does not exist

pub fn exists_already<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path exists already

pub fn extension_not_found<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path extension was not found

pub fn failed_to_string<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating a failure to convert the path to a string

pub fn filename_not_found<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path does not contain a filename

pub fn is_not_dir<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path is not a directory

pub fn is_not_exec<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path is not an executable

pub fn is_not_file<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path is not a file

Return an error indicating that the path is not a file or symlink to file

pub fn invalid_expansion<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path failed to expand properly

pub fn multiple_home_symbols<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path contains multiple user home symbols i.e. tilda

pub fn parent_not_found<T>(path: T) -> PathError
where T: AsRef<Path>,

Return an error indicating that the path does not have a valid parent path