pub enum Error {
BranchNotFound(String),
FastForwardOnly,
Fungus(FuError),
Git2(Error),
NoMessageWasFound,
Progress(Error),
RepoNotFound(String),
UrlNotSet,
}Expand description
Define common error wrapper type
Variants
BranchNotFound(String)
An error indicating that the given branch was not found.
FastForwardOnly
An error indicating that only fast forwards are allowed.
Fungus(FuError)
An error from fungus which might contain more errors
Git2(Error)
Git2 wrapped error
NoMessageWasFound
An error indicating that no message was found.
Progress(Error)
RepoNotFound(String)
An error indicating that the given repo was not found.
UrlNotSet
An error indicating that the URL was not set for the repo.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn branch_not_found<T>(pkg: T) -> Error
pub fn branch_not_found<T>(pkg: T) -> Error
Return an error indicating that the given branch was not found.
Sourcepub fn repo_not_found<T>(repo: T) -> Error
pub fn repo_not_found<T>(repo: T) -> Error
Return an error indicating that the given repo was not found.
Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Implemented directly on the Error type to reduce casting required
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Implemented directly on the Error type to reduce casting required
Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Implemented directly on the Error type to reduce casting required